@@ -17,7 +17,7 @@ class HeartbeatLog:
             self._start_time = time.time()
 
         curr_time = time.time()
-        if int(curr_time-self._start_time) >= self._interval_val and logger != None:
+        if round(int(curr_time-self._start_time)) >= self._interval_val and logger != None:
             ori_fmtter = logger.root.handlers[0].formatter
             new_fmtter = logging.Formatter("%(asctime)s — " + self._name + " — %(funcName)s:%(lineno)d — %(levelname)s — %(message)s")
             logger.root.handlers[0].setFormatter(new_fmtter)
